@@ -12,7 +12,7 @@
 #' This function computes and plots the mean runs scored by the batsman against different
 #' oppositions
 #' @usage
-#' batsmanRunsAgainstOpposition(df, name= "A Leg Glance")
+#' batsmanRunsAgainstOpposition(df, name= "A Leg Glance",staticIntv=1)
 #'
 #' @param df
 #' Data frame
@@ -20,6 +20,9 @@
 #' @param name
 #' Name of batsman
 #'
+#' @param staticIntv
+#' Static or interactive -staticIntv =1 (static plot) &  staticIntv =2 (interactive  plot)
+#'
 #' @return None
 #' @references
 #' \url{https://cricsheet.org/}\cr
@@ -47,17 +50,33 @@
 #' @export
 #'
 
-batsmanRunsAgainstOpposition <- function(df,name= "A Leg Glance"){
+
+batsmanRunsAgainstOpposition <- function(df,name= "A Leg Glance",staticIntv=1){
     batsman = runs = opposition = meanRuns =  NULL
+    ggplotly=NULL
     b <- select(df,batsman,runs,opposition)
     c <-b[complete.cases(b),]
     d <- summarise(group_by(c,opposition),meanRuns=mean(runs),numMatches=n())
     plot.title = paste(name,"- Mean runs against opposition")
-    ggplot(d, aes(x=opposition, y=meanRuns, fill=opposition))+
-        geom_bar(stat = "identity",position="dodge") +
-        xlab("Opposition") + ylab("Mean Runs") +
-        geom_hline(aes(yintercept=50))+
-        ggtitle(bquote(atop(.(plot.title),
-                            atop(italic("Data source:http://cricsheet.org/"),""))))+
-        theme(axis.text.x = element_text(angle = 90, hjust = 1))
+
+    if(staticIntv ==1){ #ggplot2
+        ggplot(d,height=600, aes(x=opposition, y=meanRuns, fill=opposition))+
+            geom_bar(stat = "identity",position="dodge") +
+            xlab("Opposition") + ylab("Mean Runs") +
+            geom_hline(aes(yintercept=50))+
+            ggtitle(bquote(atop(.(plot.title),
+                                atop(italic("Data source:http://cricsheet.org/"),""))))+
+            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+    } else { #ggplotly
+
+        g <- ggplot(d, aes(x=opposition, y=meanRuns, fill=opposition))+
+            geom_bar(stat = "identity",position="dodge") +
+            xlab("Opposition") + ylab("Mean Runs") +
+            geom_hline(aes(yintercept=50))+
+            ggtitle(plot.title) +
+            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+
+        ggplotly(g,height=600)
+    }
+
 }
