@@ -1,27 +1,33 @@
 ##########################################################################################
 # Designed and developed by Tinniam V Ganesh
-# Date : 5 Jan 2021
+# Date : 28 Jan 2021
 # Function: rankT20Bowlers
-# This function ranks the  bowlers
-# ranks the  batsmen
+# This function ranks the t20 bowlers
 #
 ###########################################################################################
 #' @title
 #' Ranks the T20 bowlers
 #'
 #' @description
-#' This function creates a single datframe of all T20 batsmen and then ranks them
-#' @usage
-#' rankT20Bowlers(dir='.',odir=".",minMatches=20)
+#' This function creates a single datframe of all T20 bowlers and then ranks them
 #'
-#' @param dir
-#' The input directory
+#' @usage
+#' rankT20Bowlers(teamNames,odir=".",minMatches, yearSelected, wicketsVsER)
+#'
+#' @param teamNames
+#' The team names
 #'
 #' @param odir
 #' The output directory
 #'
 #' @param minMatches
-#' Minimum matches
+#' Minimum matches played
+#'
+#' @param yearSelected
+#'  Selected year
+#'
+#' @param wicketsVsER
+#' Wickets  or economy rate
 #'
 #' @return The ranked T20 bowlers
 #' @references
@@ -34,31 +40,25 @@
 #' @note
 #' Maintainer: Tinniam V Ganesh \email{tvganesh.85@gmail.com}
 #'
-#' @examples
+#'
+#'@examples
 #' \dontrun{
-#' #
-#' t20BowlersRank <- rankT20Bowlers()
+#' rankT20Bowlers(teamNames,odir=".",minMatches, yearSelected, wicketsVsER)
 #' }
 #'
 #' @seealso
-#' \code{\link{rankIPLBowlers}}\cr
 #' \code{\link{rankODIBowlers}}\cr
 #' \code{\link{rankODIBatsmen}}\cr
 #' \code{\link{rankT20Batsmen}}\cr
+#' \code{\link{rankT20Bowlers}}\cr
 #' @export
 #'
-rankT20Bowlers <- function(dir='.',odir=".",minMatches=20) {
-    bowlingDetails=bowler=wickets=economyRate=matches=meanWickets=meanER=totalWickets=NULL
+rankT20Bowlers <- function(teamNames,odir=".",minMatches, yearSelected, wicketsVsER) {
+    bowlingDetails=bowler=wickets=economyRate=matches=meanWickets=meanER=totalWickets=year=NULL
     wicketPlayerOut=opposition=venue=NULL
+    teams = unlist(teamNames)
     currDir= getwd()
-    teams <-c("Australia","India","Pakistan","West Indies", 'Sri Lanka',
-              "England", "Bangladesh","Netherlands","Scotland", "Afghanistan",
-              "Zimbabwe","Ireland","New Zealand","South Africa","Canada",
-              "Bermuda","Kenya","Hong Kong","Nepal","Oman","Papua New Guinea",
-              "United Arab Emirates","Namibia","Cayman Islands","Singapore",
-              "United States of America","Bhutan","Maldives","Botswana","Nigeria",
-              "Denmark","Germany","Jersey","Norway","Qatar","Malaysia","Vanuatu",
-              "Thailand")
+
     #Change dir
     setwd(odir)
     bowlingDF<-NULL
@@ -80,12 +80,25 @@ rankT20Bowlers <- function(dir='.',odir=".",minMatches=20) {
         details <- bowlingDetails
         bowlingDF <- rbind(bowlingDF,details)
     }
+
+    maxDate= max(bowlingDF$date)
+    minDate= min(bowlingDF$date)
+    maxYear = lubridate::year(maxDate)
+    minYear = lubridate::year(minDate)
+    cat("year selected**********************=",yearSelected,"\n")
+
+    # Filter out from data frame greater than date
+    dateValue=as.Date(paste(yearSelected,"-01-01",sep=""))
+    if (dateValue < minDate)
+        dateValue=minDate
+    df=bowlingDF %>% filter(date > as.Date(dateValue))
+
     # Compute number of matches played
-    a=bowlingDF %>% select(bowler,date) %>% unique()
+    a=df %>% select(bowler,date) %>% unique()
     b=summarise(group_by(a,bowler),matches=n())
 
     # Compute wickets
-    c <- filter(bowlingDF,wicketPlayerOut != "nobody")
+    c <- filter(df,wicketPlayerOut != "nobody")
     d <- select(c,bowler,wicketPlayerOut,economyRate,date,opposition,venue)
     e <- summarise(group_by(d,bowler,date,economyRate),wickets=length(unique(wicketPlayerOut)))
     f=summarise(group_by(e,bowler), totalWickets=sum(wickets),meanER=mean(economyRate))
@@ -95,7 +108,13 @@ rankT20Bowlers <- function(dir='.',odir=".",minMatches=20) {
     g[is.na(g)] <- 0
     h <- filter(g,matches >= minMatches)
     setwd(currDir)
-    T20BowlersRank <- arrange(h,desc(totalWickets),desc(meanER))
+    if(wicketsVsER == "Wickets over Economy rate"){
+          T20BowlersRank <- arrange(h,desc(totalWickets),desc(meanER))
+    } else if(wicketsVsER == "Economy rate over Wickets"){
+
+        T20BowlersRank <- arrange(h,meanER,desc(totalWickets))
+    }
     T20BowlersRank <- distinct(T20BowlersRank)
     T20BowlersRank
+
 }
