@@ -12,7 +12,7 @@
 #' This function computes performance of bowlers of a team against an opposition in a match
 #'
 #' @usage
-#' teamBowlersVsBatsmenMatch(match,theTeam,opposition, plot=TRUE)
+#' teamBowlersVsBatsmenMatch(match,theTeam,opposition, plot=1)
 #'
 #' @param match
 #' The data frame of the match. This can be obtained with the call for e.g
@@ -26,7 +26,7 @@
 #' The opposition team
 #'
 #' @param plot
-#' This parameter specifies if a plot is required, If plot=FALSE then a data frame is returned
+#' plot=1 (static),plot=2(interactive),plot=3(table)
 #'
 #' @return None or dataframe
 #' If plot=TRUE there is no return. If plot=TRUE then the dataframe is returned
@@ -60,16 +60,17 @@
 #'
 #' @export
 #'
-teamBowlersVsBatsmenMatch <- function(match,theTeam,opposition, plot=TRUE){
+teamBowlersVsBatsmenMatch <- function(match,theTeam,opposition, plot=1){
 
     batsman=runsConceded=team=runs=bowler=NULL
+    ggplotly=NULL
     bowler=batsman=NULL
     c <- filter(match,team !=theTeam)
     b <-summarise(group_by(c,bowler,batsman),sum(runs))
     names(b) <- c("bowler","batsman","runsConceded")
 
     # Output plot or dataframe
-    if(plot == TRUE){
+    if(plot == 1){ #ggplot2
         plot.title <- paste(theTeam,"Bowler vs Batsman (against",opposition,")")
         p <- ggplot(data=b,aes(x=batsman,y=runsConceded,fill=factor(batsman))) +
             facet_grid(. ~ bowler) + geom_bar(stat="identity") +
@@ -79,6 +80,14 @@ teamBowlersVsBatsmenMatch <- function(match,theTeam,opposition, plot=TRUE){
             theme(plot.title = element_text(size=14, face="bold.italic",margin=margin(10)))
 
         p
+    }  else if(plot == 2){ #ggplotly
+        plot.title <- paste(theTeam,"Bowler vs Batsman (against",opposition,")")
+        p <- ggplot(data=b,aes(x=batsman,y=runsConceded,fill=factor(batsman))) +
+            facet_grid(. ~ bowler) + geom_bar(stat="identity") +
+            ggtitle(plot.title) +
+            theme(axis.text.x = element_text(angle = 90, hjust = 1)) +
+            theme(plot.title = element_text(size=14, face="bold.italic",margin=margin(10)))
+           ggplotly(p)
     }
     else{
         b
